@@ -1,6 +1,9 @@
+import importlib.resources as pkg_resources
 import json
 import ast
 
+from epibox import common
+
 
 def get_default(username):
 
@@ -12,8 +15,9 @@ def get_default(username):
             defaults = ast.literal_eval(defaults)
 
     except Exception as e:  # the first time using EpiBOX Core, there will be no default file
-        with open("./default_args.json") as d:
-            defaults = json.load(d)
+        defaults = ast.literal_eval(
+            pkg_resources.read_text(common, "default_args.json")
+        )
 
         with open(
             "/home/{}/Documents/epibox/args.json".format(username), "w+"
